
"""Main binary to launch a stand alone Reverb RB server."""

import os

from absl import app
from absl import flags

from circuit_training.learning import ppo_reverb_server_lib

flags.DEFINE_string('root_dir', os.getenv('TEST_UNDECLARED_OUTPUTS_DIR'),
                    'Root directory for writing logs/summaries/checkpoints.')
flags.DEFINE_integer(
    'replay_buffer_capacity', 1024,
    'Capacity of the replay buffer table. Please set this to '
    'larger than num_episodes_per_iteration.')
flags.DEFINE_integer('port', None, 'Port to start the server on.')
flags.DEFINE_integer(
    'global_seed', 55,
    'Used in env and weight initialization, does not impact action sampling.')

FLAGS = flags.FLAGS


def main(_):
  # Create the path for the serialized collect policy.
  root_dir = os.path.join(FLAGS.root_dir, str(FLAGS.global_seed))
  ppo_reverb_server_lib.start_reverb_server(root_dir,
                                            FLAGS.replay_buffer_capacity,
                                            FLAGS.port)


if __name__ == '__main__':
  flags.mark_flags_as_required(['root_dir', 'port'])
  app.run(main)